@@ -23,6 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "authenticator.h"
 #include "noaccessnetworkaccessmanagerfactory.h"
 #include "wallpaper_integration.h"
+#include <config-kscreenlocker.h>
 
 // KDE
 #include <KAuthorized>
@@ -42,6 +43,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KWayland/Client/registry.h>
 #include <KWayland/Client/surface.h>
 // Qt
+#include <QClipboard>
 #include <QAbstractNativeEventFilter>
 #include <QtCore/QTimer>
 #include <QtGui/QKeyEvent>
@@ -66,6 +68,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 #include <xcb/xcb.h>
 
+#if HAVE_SECCOMP
+#include <sys/stat.h>
+#include <unistd.h>
+#endif
+
 // this is usable to fake a "screensaver" installation for testing
 // *must* be "0" for every public commit!
 #define TEST_SCREENSAVER 0
@@ -97,12 +104,12 @@ UnlockApp::UnlockApp(int &argc, char **argv)
     , m_testing(false)
     , m_ignoreRequests(false)
     , m_immediateLock(false)
-    , m_authenticator(new Authenticator(this))
     , m_graceTime(0)
     , m_noLock(false)
     , m_defaultToSwitchUser(false)
     , m_wallpaperIntegration(new WallpaperIntegration(this))
 {
+    m_authenticator = createAuthenticator();
     connect(m_authenticator, &Authenticator::succeeded, this, &QCoreApplication::quit);
     initialize();
     connect(this, &UnlockApp::screenAdded, this, &UnlockApp::desktopResized);
@@ -130,6 +137,19 @@ UnlockApp::~UnlockApp()
     }
 }
 
+Authenticator *UnlockApp::createAuthenticator()
+{
+#if HAVE_SECCOMP
+    struct stat buf;
+    stat(KCHECKPASS_BIN, &buf);
+    if (!(buf.st_mode & S_ISUID)) {
+        m_supportsSeccomp = true;
+        return new Authenticator(AuthenticationMode::Delayed, this);
+    }
+#endif
+    return new Authenticator(AuthenticationMode::Direct, this);
+}
+
 void UnlockApp::initialize()
 {
     initializeWayland();
@@ -210,6 +230,8 @@ void UnlockApp::loadWallpaperPlugin(KQuickAddons::QuickViewSharedEngine *view)
             QQmlExpression expr(qmlObject->engine()->rootContext(), item, QStringLiteral("parent"));
             QQmlProperty prop(item, QStringLiteral("anchors.fill"));
             prop.write(expr.evaluate());
+
+            view->rootContext()->setContextProperty(QStringLiteral("wallpaper"), item);
         }
     );
 }
@@ -361,6 +383,8 @@ void UnlockApp::markViewsAsVisible(KQuickAddons::QuickViewSharedEngine *view)
     showProperty.write(true);
     // random state update, actually rather required on init only
     QMetaObject::invokeMethod(this, "getFocus", Qt::QueuedConnection);
+    QGuiApplication::clipboard()->clear();
+    QGuiApplication::clipboard()->clear(QClipboard::Selection);
 }
 
 void UnlockApp::getFocus()
